.. _faq-index:

##################
The Matplotlib FAQ
##################

.. htmlonly::

   :Release: |version|
   :Date: |today|

   Frequently asked questions about matplotlib

.. toctree::
   :maxdepth: 2

   installing_faq.rst
   howto_faq.rst
   troubleshooting_faq.rst
   environment_variables_faq.rst
   virtualenv_faq.rst
   osx_framework.rst
